package com.mycompany.moduloseguridad.dao;

import org.json.JSONObject;

public interface TipoUsuarioDAO {

    JSONObject listarProyectos() throws Exception;

    JSONObject listarTiposUsuarios(int codigoProyecto) throws Exception;

    JSONObject asignarAcciones(JSONObject datos) throws Exception;

    JSONObject activarDesactivarAccion(JSONObject datos) throws Exception;

    JSONObject activarDesactivarTipoUsuario(JSONObject datos) throws Exception;

    JSONObject listarAcciones(JSONObject datos) throws Exception;

    JSONObject listarCboAcciones() throws Exception;

    JSONObject listadoPrincipal(String filtro, int filtrado, int proyecto, int vstart, int vlength, String draw, int estado) throws Exception;

    int activarTipoUsuario(int codigo) throws Exception;

    int desactivarTipoUsuario(int codigo) throws Exception;

    int editarTipoUsuario(int codigo, String nombre) throws Exception;

    int crearTipoUsuario(String nombre) throws Exception;

    int validarTipoUsuario(int codigo) throws Exception;

    int validarNombreTipoUsuario(String nombreInicial, String nombreIngreso, int tipo) throws Exception;
}